# -*- coding: utf-8 -*-
from setuphelpers import *
import configparser


repos_to_remove = []


def install():
    if not isdir(get_public_persistent_dir()):
        mkdirs(get_public_persistent_dir())
    filecopyto(r"WAPT\public_persistent\waptconsole.ini", get_public_persistent_dir())


def uninstall():
    remove_file(get_public_persistent_file("waptconsole.ini"))


def session_setup():
    user_local_waptconsole_ini = makepath(user_local_appdata, "waptconsole", "waptconsole.ini")
    new_local_waptconsole_ini = get_public_persistent_file("waptconsole.ini")

    mkdirs(makepath(user_local_appdata, "waptconsole"))
    if not isfile(user_local_waptconsole_ini):
        inifile_writestring(user_local_waptconsole_ini, "wapt-templates", "repo_url", "https://store.wapt.fr/wapt")

    new_inifile = configparser.RawConfigParser()
    new_inifile.read(new_local_waptconsole_ini)

    user_inifile = configparser.RawConfigParser()
    user_inifile.read(user_local_waptconsole_ini)

    # Comparing ini files
    sections_updated = False
    for section in new_inifile.sections():
        if section not in ["global", "waptwua"] and section not in user_inifile.sections():
            print(f"[{section}] added")
            sections_updated = True
            if not user_inifile.has_section(section):
                user_inifile.add_section(section)
            user_inifile.set(section, "repo_url", new_inifile[section]["repo_url"])
            user_inifile.set(section, "public_certs_dir", makepath(WAPT.wapt_base_dir, "trusted_external_certs"))
    for section in user_inifile.sections():
        if section in repos_to_remove:
            print(f"[{section}] removed")
            sections_updated = True
            user_inifile.remove_section(section)
    if sections_updated:
        print("WAPT repos updated in WAPT Console")
        user_inifile.write(open(user_local_waptconsole_ini, "w"))


def get_public_persistent_dir():
    """
    Get the path to the public persistent directory.

    Returns:
        str: Path to the public persistent directory.
    """
    try:
        return makepath(WAPT.wapt_base_dir, "public", "persistent")
    except Exception:
        if get_os_name() == "Windows":
            try:
                return makepath(installed_softwares(uninstallkey="WAPT_is1")[0]["install_location"], "public", "persistent")
            except Exception:
                return makepath(programfiles32, "wapt", "public", "persistent")
        else:
            return "/opt/wapt/public/persistent"


def get_public_persistent_file(file_name):
    """
    Get the path to a file in the public persistent directory.

    Args:
        fname (str): Filename.

    Returns:
        str: Path to the file in the public persistent directory.
    """
    file_name = os.path.basename(file_name)
    return makepath(get_public_persistent_dir(), file_name)
